>From 742f0d6941a64bbc78d4f82159d96cf7d130652d Mon Sep 17 00:00:00 2001
From: Grigori Goronzy <greg@blackbox>
Date: Mon, 22 Aug 2011 01:40:54 +0200
Subject: [PATCH] libass: match font attachments based on extension

Sometimes fonts are muxed with the wrong MIME type, but we should
still be able to use them. Especially OpenType font collections are
affected by this. Match attachments by extensions .ttf, .otf and .ttc
in addition to MIME type to fix these issues.
---
 modules/codec/libass.c |   12 ++++++++++++
 1 files changed, 12 insertions(+), 0 deletions(-)

diff --git a/modules/codec/libass.c b/modules/codec/libass.c
index 5f8d9ef..8d07104 100644
--- a/modules/codec/libass.c
+++ b/modules/codec/libass.c
@@ -189,8 +189,20 @@ static int Create( vlc_object_t *p_this )
     for( int k = 0; k < i_attachments; k++ )
     {
         input_attachment_t *p_attach = pp_attachments[k];
+        bool found = false;
+
+        if( strlen( p_attach->psz_name ) > 4 )
+        {
+            char *ext = p_attach->psz_name + strlen( p_attach->psz_name ) - 4;
+
+            if( !strcasecmp( ext, ".ttf" ) || !strcasecmp( ext, ".otf" ) || !strcasecmp( ext, ".ttc" ) )
+                found = true;
+        }
 
         if( !strcasecmp( p_attach->psz_mime, "application/x-truetype-font" ) )
+            found = true;
+
+        if( found )
         {
             msg_Dbg( p_dec, "adding embedded font %s", p_attach->psz_name );
 
-- 
1.7.2.3

